Stan Math Library: stan/math/prim/mat/fun/simplex_free.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

simplex_free.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_SIMPLEX_FREE_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_SIMPLEX_FREE_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/err/check_simplex.hpp>
6 #include <stan/math/prim/mat/meta/index_type.hpp>
7 #include <stan/math/prim/scal/fun/logit.hpp>
8 #include <cmath>
9
10 namespace stan {
11
12 namespace math {
13
28 template <typename T>
29 Eigen::Matrix<T, Eigen::Dynamic, 1>
30 simplex_free(const Eigen::Matrix<T, Eigen::Dynamic, 1>& x) {
31 using Eigen::Dynamic;
32 using Eigen::Matrix;
33 using stan::math::index_type;
34 using stan::math::logit;
35 using std::log;
36
37 typedef typename index_type<Matrix<T, Dynamic, 1> >::type size_type;
38
39 stan::math::check_simplex("stan::math::simplex_free",
40 "Simplex variable", x);
41 int Km1 = x.size() - 1;
42 Eigen::Matrix<T, Eigen::Dynamic, 1> y(Km1);
43 T stick_len(x(Km1));
44 for (size_type k = Km1; --k >= 0; ) {
45 stick_len += x(k);
46 T z_k(x(k) / stick_len);
47 y(k) = logit(z_k) + log(Km1 - k);
48 // note: log(Km1 - k) = logit(1.0 / (Km1 + 1 - k));
49 }
50 return y;
51 }
52
53 }
54
55 }
56
57 #endif
check_simplex.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
stan::math::size_type
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic >::Index size_type
Type for sizes and indexes in an Eigen matrix with double e.
Definition: typedefs.hpp:13
stan::math::index_type
Primary template class for the metaprogram to compute the index type of a container.
Definition: index_type.hpp:19
index_type.hpp
Eigen.hpp
stan::math::logit
fvar< T > logit(const fvar< T > &x)
Definition: logit.hpp:17
stan::math::simplex_free
Eigen::Matrix< T, Eigen::Dynamic, 1 > simplex_free(const Eigen::Matrix< T, Eigen::Dynamic, 1 > &x)
Return an unconstrained vector that when transformed produces the specified simplex.
Definition: simplex_free.hpp:30
stan::math::check_simplex
bool check_simplex(const char *function, const char *name, const Eigen::Matrix< T_prob, Eigen::Dynamic, 1 > &theta)
Return true if the specified vector is simplex.
Definition: check_simplex.hpp:41
logit.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.